diff --git a/vlc-android/AndroidManifest.xml b/vlc-android/AndroidManifest.xml
index f4b4032..692d741 100644
--- a/vlc-android/AndroidManifest.xml
+++ b/vlc-android/AndroidManifest.xml
@@ -411,6 +411,7 @@
                 <action android:name="android.intent.action.MEDIA_BUTTON" />
             </intent-filter>
         </receiver>
+        <uses-library android:name="jp.co.sharp.android.stereo3dlcd" android:required="false" />
     </application>
 
 </manifest>
diff --git a/vlc-android/src/org/videolan/vlc/Util.java b/vlc-android/src/org/videolan/vlc/Util.java
index 344a99a..ec37826 100644
--- a/vlc-android/src/org/videolan/vlc/Util.java
+++ b/vlc-android/src/org/videolan/vlc/Util.java
@@ -27,6 +27,9 @@ import java.io.FileReader;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.InputStreamReader;
+import java.lang.Class;
+import java.lang.reflect.Constructor;
+import java.lang.reflect.Method;
 import java.text.DecimalFormat;
 import java.text.NumberFormat;
 import java.util.HashSet;
@@ -41,6 +44,7 @@ import android.telephony.TelephonyManager;
 import android.util.DisplayMetrics;
 import android.util.TypedValue;
 import android.view.Display;
+import android.view.SurfaceView;
 import android.view.View;
 import android.view.WindowManager;
 import android.widget.Toast;
@@ -373,4 +377,47 @@ public class Util {
             return true;
         }
     }
+
+    public static final int CAP_3D_SHARP = 0x00000001;
+
+    public static boolean hasSharp3D() {
+        try {
+            Class.forName("jp.co.sharp.android.stereo3dlcd.SurfaceController");
+            return true;
+        } catch (Exception e) {
+            e.printStackTrace();
+            return false;
+        }
+    }
+
+    public static int getDevice3DCapability() {
+        int cap = 0;
+        if (hasSharp3D())
+            cap = CAP_3D_SHARP;
+        return cap;
+    }
+
+    public static void enableSharp3D(SurfaceView surface, boolean enabled) {
+        try {
+            Class clz = Class.forName("jp.co.sharp.android.stereo3dlcd.SurfaceController");
+            Constructor ctor = clz.getDeclaredConstructor(SurfaceView.class);
+            Object obj = ctor.newInstance(surface);
+            Method method = clz.getDeclaredMethod("setStereoView", boolean.class);
+            method.invoke(obj, enabled);
+        } catch (Exception e) {
+            e.printStackTrace();
+        }
+    }
+
+    public static void enable3D(SurfaceView surface, boolean enabled) {
+        int cap = getDevice3DCapability();
+        switch (cap) {
+        case CAP_3D_SHARP: {
+            enableSharp3D(surface, enabled);
+            break;
+        }
+        default:
+            break;
+        }
+    }
 }
diff --git a/vlc-android/src/org/videolan/vlc/gui/video/VideoPlayerActivity.java b/vlc-android/src/org/videolan/vlc/gui/video/VideoPlayerActivity.java
index 857a9f3..a3760a3 100644
--- a/vlc-android/src/org/videolan/vlc/gui/video/VideoPlayerActivity.java
+++ b/vlc-android/src/org/videolan/vlc/gui/video/VideoPlayerActivity.java
@@ -1047,6 +1047,20 @@ public class VideoPlayerActivity extends Activity {
     };
 
     /**
+     * toggle 3D surface
+     */
+    private final OnClickListener m3DListener = new OnClickListener() {
+        boolean is3D = false;
+
+        @Override
+        public void onClick(View v) {
+            is3D = !is3D;
+            Util.enable3D(mSurface, is3D);
+        }
+    };
+
+
+    /**
      * attach and disattach surface to the lib
      */
     private final SurfaceHolder.Callback mSurfaceCallback = new Callback() {